@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-2020 IBM Corporation
+ * Copyright 2018-2021 Elyra Authors
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,8 +14,8 @@
  * limitations under the License.
  */
 describe('Toc', () => {
-  it('opens jupyterlab', () => {
-    cy.visit('?token=test&reset');
+  beforeEach(() => {
+    cy.openJupyterLab();
   });
 
   it('opens ToC extension', () => {
